
C=======================================================================
      MODULE ControlParams
C=======================================================================


C     Control variables required to process land cover file

      IMPLICIT NONE
      
      CHARACTER*3  ::  fileType
      
      INTEGER      ::  nlcdType
      
      LOGICAL      ::  LC1992

      INTEGER :: istate  ! State or state region represented in data file
      INTEGER (kind=8) :: StateCols, StateRows  ! number of rows and columns in NLCD file
      INTEGER (kind=8) :: StateULX, StateULY    ! albers coordinates of upper left corner of file
      INTEGER (kind=8) :: StateLRX, StateLRY    ! albers coordinates of lower right corner of file
      
      INTEGER :: NumSeas = 4 ! number of seasons
      
      CHARACTER*10       :: big_ben(3)   ! tmp space to hold time variables
      INTEGER            :: run_start(8) ! date/time processing begins
      INTEGER            :: run_end(8)   ! date/time processing ends
      
C --- The following vars are specific for processing GeoTIFF files

      character(len=5)  :: tiffType ! data organization ('strip' || 'tile')
      
      logical   :: byteswap         ! big/little endian inconsistent between file and machine
      
      integer (kind=8)   :: rowsPerStrip      ! number of data rows per strip
      integer (kind=8)   :: tileLen           ! length (height) of tile in pixels
      integer (kind=8)   :: tileWid           ! width of tile in pixels
      integer (kind=8)   :: bytesPerSample    ! number of bytes per data sample
            
      double precision   :: tiePtx    ! upper left X coordinate GeoTIFF
      double precision   :: tiePty    ! upper left Y coordinate GeoTIFF 
      double precision   :: tiePtz    ! upper left Z coordinate GeoTIFF (should be zero)
      double precision   :: pxlScalex ! model pixel scale X-direction
      double precision   :: pxlScaley ! model pixel scale Y-direction 
      double precision   :: pxlScalez ! model pixel scale Z-direction (should be zero or one)
       
      
      integer (kind=8), allocatable :: dataOS(:)  ! offsets (in bytes) to data strips or tiles  
      
      INTEGER (kind=8) :: StudyCenterCol, StudyCenterRow ! center col and row      
      DOUBLE PRECISION :: CntrAlbersX, CntrAlbersY  ! center of study area in Albers coords.
      
      DOUBLE PRECISION :: CellRes                ! grid resolution at center of study area (meters)
      
      DOUBLE PRECISION :: EdgeAlbersX, EdgeAlbersY  ! edge of the study area on y-axis from center, Albers coords.
      DOUBLE PRECISION :: EdgeLat, EdgeLon  ! edge of studay area on y-axis from center, lat/lon
      
      DOUBLE PRECISION :: GridToTruDif ! degrees difference in grid north to true north
      
      DOUBLE PRECISION :: StudyRadiusBaMeters, StudyRadiusZ0Meters ! length of study radii in meters
      DOUBLE PRECISION :: StudyRadiusMaxMeters  ! max length of study radiiu
      DOUBLE PRECISION :: StudyRadiusMax  ! maximum of StudyRadiusBa and StudyRadiusZ0
      
      INTEGER (kind=8) :: StudyRadiusBaAsCells  ! study radius in cell lengths (Bowen and albedo)
      INTEGER (kind=8) :: StudyRadiusZ0AsCells  ! study radius in cell lengths (Z0)
      INTEGER (kind=8) :: StudyRadiusMaxAsCells ! study radius in cell lengths (max of B, a, and Z0) 


	   
      INTEGER (kind=8), ALLOCATABLE   :: ZoGrid(:,:)   ! array to hold cell values used for Z0 for output
      INTEGER (kind=8)                :: ZoGridNRows   ! number of rows for Z0 grid
      INTEGER (kind=8)                :: ZoGridNCols   ! number of cols for Z0 grid
      INTEGER (kind=8)                :: ZoGridFrstRow ! first row of Z0 grid
      INTEGER (kind=8)                :: ZoGridLastRow ! last row of Z0 grid
      INTEGER (kind=8)                :: ZoGridFrstCol ! first row of Z0 grid
      INTEGER (kind=8)                :: ZoGridLastCol ! last row of Z0 grid
      INTEGER (kind=8)                :: ZoGridRowCnt  ! counter for filling array
      INTEGER (kind=8)                :: ZoGridColCnt  ! counter for filling array
  
      INTEGER (kind=8), ALLOCATABLE   :: BaGrid(:,:)   ! array to hold cell values used for Ba for output
      INTEGER (kind=8)                :: BaGridNRows   ! number of rows for bowen/albedo grid
      INTEGER (kind=8)                :: BaGridNCols   ! number of cols for bowen/albedo grid	   
      INTEGER (kind=8)                :: BaGridFrstRow ! first row of bowen ratio and albedo grid
      INTEGER (kind=8)                :: BaGridLastRow ! last row of bowen ratio and albedo grid
      INTEGER (kind=8)                :: BaGridFrstCol ! first row of bowen ratio and albedo grid
      INTEGER (kind=8)                :: BaGridLastCol ! last row of bowen ratio and albedo grid
      INTEGER (kind=8)                :: BaGridRowCnt  ! counter for filling array
      INTEGER (kind=8)                :: BaGridColCnt  ! counter for filling array

      INTEGER (kind=8)                :: GridFrstRow, GridLastRow
      INTEGER (kind=8)                :: GridFrstCol, GridLastCol      


      END MODULE ControlParams
