
C=======================================================================
      MODULE LandCoverParams
C=======================================================================

C     NumLCTypes = Number of Land Cover Types; the number is set to 100
C                  rather than the actual number so we can easily match
C                  land cover class number in the table with the
C                  correspomnding one in this array; otherwise, we
C                  would have to create a mapping of table class numbers
C                  to array elements
C                  array limits are 0 to 99 where 0 indicates cell is
C                  outside state boundary and 99 becomes the category
C                  for missing land cover (in an NLCD file, the value
C                  for missing data is -9999 so we map it to category 99)

C     Albedo, Z0, BowenAvg, BowenWet, BowenDry = albedo; roughness
C                  length; and average, wet, dry Bowen ratios
C     SeasVar = Number of seasonal variances (winter is broken into
C                  two variances to indicate snow or no snow)

C     Modification: This set of values provided by EPA on 6/21/2007
C-----------------------------------------------------------------------
      IMPLICIT NONE
      SAVE

      INTEGER, PARAMETER :: NumLCTypes = 100
      INTEGER, PARAMETER :: SeasVar = 5 ! 1-Wnt w/o snow, 2-Wnt w/snow
                                        ! 3,4,5 - Spr,Sum,Fall

      INTEGER :: I, J

      REAL :: Albedo(0:NumLCTypes-1,SeasVar),
     &        Albedo_Ar(0:NumLCTypes-1,SeasVar),
     &        Albedo_NAr(0:NumLCTypes-1,SeasVar),
     &        Z0(0:NumLCTypes-1,SeasVar),
     &        Z0_Airp(0:NumLCTypes-1,SeasVar),
     &        Z0_NAirp(0:NumLCTypes-1,SeasVar),
     &        Z0_Ar(0:NumLCTypes-1,SeasVar),
     &        Z0_NAr(0:NumLCTypes-1,SeasVar),
     &        Bowen(0:NumLCTypes-1,SeasVar),
     &        BowenAvg(0:NumLCTypes-1,SeasVar),
     &        BowenAvg_Ar(0:NumLCTypes-1,SeasVar),
     &        BowenAvg_NAr(0:NumLCTypes-1,SeasVar),
     &        BowenWet(0:NumLCTypes-1,SeasVar),
     &        BowenWet_Ar(0:NumLCTypes-1,SeasVar),
     &        BowenWet_NAr(0:NumLCTypes-1,SeasVar),
     &        BowenDry(0:NumLCTypes-1,SeasVar),
     &        BowenDry_Ar(0:NumLCTypes-1,SeasVar),
     &        BowenDry_NAr(0:NumLCTypes-1,SeasVar)

      TYPE NLCDCOVERAGE
            INTEGER :: ClassNum
            CHARACTER (LEN=40) ClassName
      END TYPE NLCDCOVERAGE
      
      TYPE (NLCDCOVERAGE), DIMENSION(0:NumLCTypes-1) :: LCSurfChar
      
      INTEGER   :: LCCatsAll92(21)
      
      DATA LCCatsAll92  /11,12,21,22,23,31,32,33,41,42,43,
     &                     51,61,71,81,82,83,84,85,91,92/



      END MODULE LandCoverParams
