
C=======================================================================
      MODULE UserParams
C=======================================================================

C     Declaration of user input variables and those derived from 
C     user inputs

C     DownloadType:  USER INPUT: type of land use data file
C                    (seamless or state)
C     PostalCode:    USER INPUT: 2-character state abbreviation

C     NLCDfile:      USER INPUT: land use data file
C     FileExists:    Logical indicating that a file exists
C     St3file:       USER INPUT: output file formatted for AERMET
C     Logfile:       Output log file (derived from St3file file name)

C     CoordType:     USER INPUT: Coordinate type (UTM or LATLON)
C     Datum:         USER INPUT: Dataum reference (NAD27 or NAD83)

C     CenterUTME:    USER INPUT: UTM Easting, in meters, of center of study
C     CenterUTMN:    USER INPUT: UTM Northing, in meters, of center of study
C     CenterUTMZone: USER INPUT: UTM Zone of center of study
C     CenterLatIn:   USER INPUT: latitude, in decimal degrees, of center of study
C     CenterLonIn:   USER INPUT: longitude, in decimal degrees, of center of study
C     CenterLat:     Modified USER INPUT: NAD83 latitude, in decimal degrees, of center of study
C     CenterLon:     Modified USER INPUT: NAD83 longitude, in decimal degrees, of center of study 

C     Region:        USER INPUT: Identifies region of state when state is 
C                    divided into more than one region (TX and CA)

C     AirportChr:    USER INPUT: indicates whether site is at an airport
C                    (can affect sfc roughness)
C     Airport:       Logical flag (derived), true if site is at an airport

C     AridChr:       USER INPUT: indicates if site is in an arid region
C                    (can affect albedo and bowen ratio)
C     Arid:          Logical flag (derived), true if site is in an arid region

C     SnowChr:       USER INPUT: indicates if there was snow during the winter
C                    (can affect sfc roughness, albedo, and bowen ratio)
C     Snow:          Logical flag (derived), true if snow occurred during the 
C                    winter

C     Moisture:      USER INPUT: indicates average, wet, or dry sfc moisture
C                    (A=Average, W=Wet, D=Dry; affects bowen ratio)
C     MoistStr:      Stores output label for surface moisture
C                    (Average, Wet, Dry)

C     StudyRadiusBa: USER INPUT: radius of the study area (km) for Bowen and albedo
C     StudyRadiusZ0: USER INPUT: radius of the study area (km) for sfc roughness


C     TemporalRes:   USER INPUT: resolution of sfc characteristics
C                    (A=ANNUAL, S=SEASONAL, M=MONTHLY)
C     TempResStr:    Stores output label for temporal resolution
C                    (ANNUAL, SEASONAL, MONTHLY)

C     StartDir():    USER INPUT: array of start directions for each wind sector
C     NumSectors:    USER INPUT: number of discrete wind direction sectors

C     SeasonMnths(): 1-D array to hold assignment of a season to
C                    month. Indices 1-12 represent Jan-Dec.  Each month is 
C                    assigned to a season represented by an integer value where:
C                    1=winter w/o snow, 2=winter w/ snow, 3=spring, 4=summer
C                    and 5=autumn.  Default assingment:
C                    dec-feb=winter (w/ or w/o snow based on add'l user input),
C                    mar-may=spring, jun-aug=summer, sep-nov=fall

C     WinWSnMnths:     USER INPUT: Months assigned to winter w/ continous snow
C     WinNoSnMnths:    USER INPUT: Months assigned to winter w/o continous snow
C                                  or late autumn
C     SprgMnths:       USER INPUT: Months assigned to Transitional Spring
C     SumrMnths:       USER INPUT: Months assigned to Mid-Summer lush veg
C     AutmMnths:       USER INPUT: Months assigned to Autumn unharvested crops
C                    
C-----------------------------------------------------------------------

      IMPLICIT NONE
      
      CHARACTER (LEN=132):: NLCDfile, Logfile, St3file
      CHARACTER (LEN=10) :: DownloadType
      CHARACTER (LEN=8)  :: CoordType, TempResStr
      CHARACTER (LEN=7)  :: MoistStr
      CHARACTER (LEN=5)  :: Datum
      CHARACTER (LEN=2)  :: PostalCode
      CHARACTER (LEN=2)  :: Region
      CHARACTER (LEN=1)  :: VaryBySector, TemporalRes
      
      CHARACTER (LEN=1)  :: AirportChr, AridChr, SnowChr, Moisture
      CHARACTER (LEN=1)  :: AssignMnthChr

      DOUBLE PRECISION :: CenterUTME,  CenterUTMN
      DOUBLE PRECISION :: CenterLatIn, CenterLonIn
      DOUBLE PRECISION :: CenterLat,   CenterLon
      
C --- Two study radii are defined, one for roughness and one that is 
C     used for both Bowen ratio and albedo.  
C
C     7/2/07, CRT: The radius for bowen ratio and albedo is not used  
C     as a true radius. Rather, the max of the two radii are used to 
C     determine the rows and columns to skip and those to extract. 
C     Bowen and albedo are now computed based a 10 X 10 km grid
C     and the distance from the center is ignored for these two averages.
C     Radius for Bowen and albedo is hard coded to 10 km and radius for 
C     Zo is limited to 5.0 km so the max will always be 10 km.  
      DOUBLE PRECISION :: StudyRadiusBa = 5.0D0
      DOUBLE PRECISION :: StudyRadiusZ0
      
      INTEGER :: StartDir(12)

      INTEGER :: CenterUTMZone
      INTEGER :: NumSectors

      LOGICAL :: Airport, Arid, Snow 
      Logical :: AssignMnth = .FALSE.
      
      INTEGER :: SeasonMnths(12) = 0  
      
      CHARACTER (LEN=60) :: WinWSnMnths, WinNoSnMnths, SprgMnths, 
     &                      SumrMnths, AutmMnths   



      END MODULE UserParams

