
      SUBROUTINE AvgSfcCharsGeom
      
      
C ----------------------------------------------------------------------
C     Compute geometric means for Bowen ratio and surface roughness.
C     Bowen ratio based on single area-weighted average across the domain 
C     (no sector dependency); surface roughness incorporates sector-
C     dependency and inverse-distance weighting.
C ----------------------------------------------------------------------

      USE LandCoverParams
      USE MyConstants
      USE UserParams
      USE ControlParams
      USE AvgParams

      IMPLICIT NONE
      
      
      INTEGER  :: NumMnths(NumSeas) ! number of months assigned to each of four seasons
      
      NumMnths(:) = 0

C --- For average arrays, the last element represents the 4 seasons 
C     (winter=1, spring=2, summer=3, fall=4) or 12 monts.  If averaging 
C     period is annual, average is stored in index 1, if monthly,
C     is annual, average is stored in index 1, if monthly,
C     there will be 12 monthly averages, if seasonal, averages will be
C     stored in indices 1-4 based on the AERMET mapping of
C     seasons and months:
C      Winter = January, February, December
C      Spring = March, April, May
C      Summer = June, July, August
C      Autumn = September, October, November
    
C --- compute monthly averages 
      DO i=1, NumSectors
         DO j=1, 12 ! months
 
C ---       Average roughness is the sum of the Zo values for each cell
C           (weighted by distance) divided by the sum of 1/distance
            AvgZ0(i,j) =
     &        Z0Sum(i,j)/InvDSumZo(i,j)
   
            AvgZ0(i,j) = EXP(AvgZ0(i,j))
        
C ---        Consider only 1 sector for bowen ratio
             IF( i == 1 )THEN

C ---          Average Bowen ratio is the sum of the B values for each cell
C              divided by the total number of cells
               AvgBowen(i,j) =
     &            BowenSum(i,j)/LCCountBr(i)
     
               AvgBowen(i,j) = EXP(AvgBowen(i,j))
          
             ENDIF
          
          ENDDO
       ENDDO
       
C ---  Initialize arrays       
       Z0Sum    = 0.0
       BowenSum = 0.0
         
C --- if resolution is SEASONAL, compute seasonal averages
      IF( TemporalRes == 'S' )THEN
         DO i=1, NumSectors
            DO j=1, 12 ! months
               IF( SeasonMnths(j) == 1 .OR.   
     &          SeasonMnths(j) == 2 )THEN
                  
                  IF( i == 1 )THEN
                     NumMnths(1) = NumMnths(1)+1
                  ENDIF
     
                  Z0Sum(i,1) = Z0Sum(i,1) +
     &             AvgZ0(i,j)

C ---             Consider only 1 sector for bowen ratio
                  IF( i == 1 )THEN     
                     BowenSum(i,1) = BowenSum(i,1) +
     &                AvgBowen(i,j)
                  ENDIF
     
               ELSE
                  IF( i == 1 )THEN
                     NumMnths(SeasonMnths(j)-1) = 
     &                NumMnths(SeasonMnths(j)-1) + 1
                  ENDIF
     
                  Z0Sum(i,SeasonMnths(j)-1) = 
     &             Z0Sum(i,SeasonMnths(j)-1) + AvgZ0(i,j)

C ---             Consider only 1 sector for bowen ratio
                  IF( i == 1 )THEN      
                     BowenSum(i,SeasonMnths(j)-1) = 
     &                BowenSum(i,SeasonMnths(j)-1) + AvgBowen(i,j)
                  ENDIF
               ENDIF
            ENDDO
         ENDDO

C ---    Initialize arrays
         AvgZ0    = 0.0
         AvgBowen = 0.0
         
         DO i=1, NumSectors
            DO j=1, NumSeas     
               AvgZ0(i,j) = Z0Sum(i,j)/REAL(NumMnths(j))
C ---          Consider only 1 sector for bowen ratio
               IF( i == 1 )THEN          
                  AvgBowen(i,j) = BowenSum(i,j)/REAL(NumMnths(j))
               ENDIF
            ENDDO 
         ENDDO

C     if resolution is annual         
      ELSEIF( TemporalRes == 'A' ) THEN
         DO i=1, NumSectors
            DO j=1, 12 ! months
               Z0Sum(i,1) = Z0Sum(i,1)+AvgZ0(i,j)
C ---          Consider only 1 sector for bowen ratio
               IF( i == 1 )THEN          
                  BowenSum(i,1) = BowenSum(i,1)+AvgBowen(i,j)
               ENDIF
            ENDDO          

            AvgZ0(i,1) = Z0Sum(i,1)/12.0
            
C ---       Consider only 1 sector for bowen ratio
            IF( i == 1 )THEN          
               AvgBowen(i,1) = BowenSum(i,1)/12.0
            ENDIF
         ENDDO
         
      ENDIF 

      RETURN
      END SUBROUTINE AvgSfcCharsGeom