
      SUBROUTINE AvgSfcCharsSimple

C ----------------------------------------------------------------------
C     Compute simple area-weighted arithmetic averages across the domain 
C     (no sector dependency) for albedo. 
C ----------------------------------------------------------------------

      USE LandCoverParams
      USE MyConstants
      USE UserParams
      USE ControlParams
      USE AvgParams

      IMPLICIT NONE

      INTEGER :: k ! counter
      
C --- For average arrays, the last element represents the 4 seasons 
C     (winter=1, spring=2, summer=3, fall=4) or 12 monts.  If averaging 
C     period is annual, average is stored in index 1, if monthly,
C     there will be 12 monthly averages, if seasonal, averages will be
C     stored in indices 1-4 based on the AERMET mapping of
C     seasons and months:
C      Winter = January, February, December
C      Spring = March, April, May
C      Summer = June, July, August
C      Autumn = September, October, November

    
C ---------------------------------------------------------------------
C     Begin averaging sfc characteristics by season as specified by 
C     the user.  No sector dependence for albedo and Bowen ratio.
C     Do not include cells with land use class marked as outside 
C     boundary (0 in NLCD92) or missing data (99 in NLCD92).
C
C     Current Implementation for Computing Annual Average
C     for each Sfc Characteristic (NLCD92):
C
C     (LC type = Land use Class)
C       1 Get a count of grid cells for each sector where LC type is 
C         not missing or out of bounds (99 or 0 for NLCD92).

C       2 If output is annual or monthly, compute monthly averages
C         by looping over the LC types multiplying the count of each 
C         LC type for the domain by the value of the sfc characteristic for 
C         the season the for which the month is assigned.  Keep a running
C         sum of the computation for each month across all LC types.

C       3 Compute an average for each month by dividing the total
C         computed for the month by the total count of grid cells in the domain
C         (excluding missing or out of bounds)

C       4 If output is to be annual, compute an annual average by summing the 
C         monthly averages and dividing by 12 (number of months). 

C       5 If output is seasonal, loop over 4 seasons (restricted to 4 since
C         all of winter must be considered to have continuous snow or wthout
C         continuous snow.) For each season loop over all
C         LC types multiplying the count of each type by the value
C         of the sfc characteristic for the current season.  Keep
C         a running sum across all LC Types for each season.

C       6 Compute an average seasonal value by dividing the sum for each season
C         by the number of grid cells (exclude missing or out of bounds).
C ---------------------------------------------------------------------


c --- compute monthly averages for both annual and monthly resolution
c --- annual average will then be computed from monthly average

c --- get sum of values for each surface characteristic by month
      IF( TemporalRes == 'A' .OR. TemporalRes == 'M') THEN
c     ignore sectors, treat as one sector
c         DO i=1, NumSectors
         DO i=1, 1
c           for LCTypes, exclude outside border and missing
            DO j=0, NumLCTypes-1
               DO k=1, 12  ! 12 months/year
                  IF( j /= MissCode )THEN
                     AlbSum(i,k) =
     &                  AlbSum(i,k)+
     &                 (REAL(LandCoverAlb(i,j))*
     &                  Albedo(j,SeasonMnths(k)))
                  ENDIF
               ENDDO
            ENDDO
         ENDDO
         
c ------ compute monthly averages 
c        ignore sectors; treat as one sector
c         DO i=1, NumSectors
         DO i=1, 1
            DO j=1, 12 ! months
               AvgAlbedo(i,j) =
     &            AlbSum(i,j)/REAL(LCCountAlb(i))
            ENDDO
         ENDDO
         
c ------ compute annual average if resolution is annual
         IF( TemporalRes == 'A' )THEN
c        ignore sectors; treat as one sector
c            DO i=1, NumSectors
            DO i=1, 1
               AlbSum(i,1) = 0.0
               DO j=1, 12 ! months
                  AlbSum(i,1) = AlbSum(i,1)+AvgAlbedo(i,j)
               ENDDO
               AvgAlbedo(i,1) = AlbSum(i,1)/12.0
            ENDDO
         ENDIF

c     seasonal
      ELSE
c     ignore sectors; treat as one sector
c         DO i=1, NumSectors
         DO i=1, 1
c           for LCTypes, exclude outside border and missing data
            DO j=0, NumLCTypes-1
               DO k=1, NumSeas
                  IF( j /= MissCode )THEN
                     IF( k == 1 .AND. .NOT. Snow )THEN
                        AlbSum(i,k) =
     &                     AlbSum(i,k)+
     &                     (REAL(LandCoverAlb(i,j))*Albedo(j,1))
                     ELSE
                        AlbSum(i,k) =
     &                     AlbSum(i,k)+
     &                     (REAL(LandCoverAlb(i,j))*Albedo(j,k+1))
                     ENDIF
                  ENDIF
               ENDDO
            ENDDO
         ENDDO

C        now compute season averages
c        ignore sectors; treat as one sector
c         DO i=1, NumSectors
         DO i=1, 1
            DO j=1, NumSeas
               AvgAlbedo(i,j) =
     &            AlbSum(i,j)/REAL(LCCountAlb(i))
           ENDDO
         ENDDO
      ENDIF


      RETURN
      END SUBROUTINE AvgSfcCharsSimple