      SUBROUTINE InitControlParams
 
C ----------------------------------------------------------------------     
C     InitControlParams
C        Initialize control parameters needed to read through NLCD data
C        file.  If file is a TIFF file, these parameters are derived
C        from the tags within the TIFF file.  BIN files (state only)
C        are initialized from the hard coded data.  Based on the postal
C        entered by the user.
C ----------------------------------------------------------------------
       
      USE AlbersProjectionData
      USE MyConstants
      USE UserParams
      USE FileUnits
      USE ControlParams
      
      Implicit None

c --- .tif files - get info from tiff file
      IF (fileType == 'tif') THEN

c ---    read nlcd tiff file tags and geokeys 
         
         CALL read_tifftags(NLCDfile,inUnt,LogFile,LogUnt,
     &                      .true.,TIFFDbgFile,TIFFDbgUnt)
         CALL proc_tifftags

     
c --- .bin files - get values from hard coded projection data
      ELSE
 
         StateCols = STATEINFO(istate) % NumCols
         StateRows = STATEINFO(istate) % NumRows
         StateULX  = STATEINFO(istate) % ULX
         StateULY  = STATEINFO(istate) % ULY
         StateLRX  = STATEINFO(istate) % LRX
         StateLRY  = STATEINFO(istate) % LRY

         
c ---    set the datum of the file, assumed to be NAD83
         LCDatum = "NAD83"
         
c ---    set data offset to mimic a single strip tiff file
         allocate(dataOS(1))
         dataOS(1) = 0_8
         
c ---    set rows per strip to mimic a single strip tiff file
         rowsPerStrip = StateCols
         
c ---    set tiffType to mimic single strip tiff file
         tiffType = "strip"
         
c ---    set cell resolution
         CellRes = 30.0D0
         
c ---    set bytes per sample
         bytesPerSample = 1

c ---    set projection parameters for binary files (these are only 1992 state files)
         Esquared = 0.006694380D0
         EarthRadius = 6378137.0D0
         CentMeridian = -96.0D0
         ProjOrigin   = 23.0D0
         StdParallel1 = 29.5D0
         StdParallel2 = 45.5D0         
       
      ENDIF

      
      END Subroutine InitControlParams