
      SUBROUTINE WriteSfcChars

C ---------------------------------------------------------------------
C     Output averaged surface characteristic values (B, albedo, Z0) to
C     file in format for input into AERMET
C
C ---------------------------------------------------------------------


      USE LandCoverParams
      USE MyConstants
      USE UserParams
      USE FileUnits
      USE ControlParams
      USE AvgParams

      IMPLICIT NONE
      
      INTEGER :: EndDir
      
      INTEGER :: NumFreq

C --- Determine frequency based on temporal resolution
      IF( TemporalRes == 'A' )THEN
         NumFreq = 1
      ELSEIF( TemporalRes == 'S' )THEN
         NumFreq = 4
      ELSEIF( TemporalRes == 'M' ) THEN
         NumFreq = 12
      ENDIF

C ---------------------------------------------------------------------
C     Write to output file
C ---------------------------------------------------------------------

C --- output temporal resolution and number of sectors
      WRITE(OutUnt,100) trim(adjustl(TempResStr)), NumSectors
  100 FORMAT(/,'   FREQ_SECT  ',A,I3)

C --- output the beginning and ending direction for each sector

C --- the end direction is the start direction for the next sector
C --- if the last sector ends at north, direction should be 360.0
      DO i=1,NumSectors
         IF( i == NumSectors .AND. StartDir(1) /= 0) THEN
            EndDir = StartDir(1)
         ELSEIF( i == NumSectors .AND. StartDir(1) == 0) THEN
            EndDir = 360
         ELSE
            EndDir = StartDir(i+1)
         ENDIF
         WRITE(OutUnt,200), i, StartDir(i), EndDir
      ENDDO
  200 FORMAT( '   SECTOR ',I3,2I5)
  
C --- Add comment to output file to indicate the order the 
C     the sfc chars. are output
      IF( TemporalRes == 'M' )THEN
         WRITE(OutUnt,250) '**           Month    Sect    Alb',
     &      '      Bo        Zo'
      ELSEIF( TemporalRes == 'S' )THEN
         WRITE(OutUnt,250) '**           Season   Sect    Alb',
     &      '      Bo        Zo'
      ELSE
         WRITE(OutUnt,250) '**                    Sect    Alb',
     &      '      Bo        Zo'
      ENDIF
  250 FORMAT(2a)  
C --- Output the site characteristics for each sector (i) for each
C     frequency index (j, i.e., 1=annual, 4=seasonal, 12=monthly).
C --- For monthly, replicate seasons according to AERMET 
C     (Winter = Dec, Jan, Feb; Spring = Mar, Apr, May, etc.)


      DO j=1,NumFreq
         DO i=1,NumSectors       

C           bowen ratio and albedo - treat as one sector; each sector gets 
C           the same value - stored as sector 1

C ---       ANNUAL and SEASONAL; 

            IF( NumFreq < 12 )THEN
               WRITE(OutUnt,300) j,i,AvgAlbedo(1,j),AvgBowen(1,j),
     &                       AvgZ0(i,j)
C ---       MONTHLY
            ELSEIF( NumFreq == 12 )THEN
               WRITE(OutUnt,300) j,i,
     &            AvgAlbedo(1,j),
     &            AvgBowen(1,j), 
     &            AvgZ0(i,j)                 
           
            ENDIF
         ENDDO
      ENDDO
      
  300 FORMAT( '   SITE_CHAR  ',I3,5x,I3,F9.2,F9.2,F10.3)

      RETURN
      
      END SUBROUTINE WriteSfcChars